Class: TelegramBot::ReplyKeyboardHide
- Defined in:
- lib/telegram_bot/reply_keyboard_hide.rb
Overview
Upon receiving a message with this object, Telegram clients will hide the current custom keyboard and display the default letter-keyboard. By default, custom keyboards are displayed until a new keyboard is sent by a bot. An exception is made for one-time keyboards that are hidden immediately after the user presses a button (see ReplyKeyboardMarkup).
Instance Method Summary collapse
Instance Method Details
#to_h ⇒ Object
24 25 26 27 28 |
# File 'lib/telegram_bot/reply_keyboard_hide.rb', line 24 def to_h h = { hide_keyboard: true } h[:selective] = selective unless selective.nil? h end |